import {Component, ElementRef, Renderer2, ViewChild} from '@angular/core';
import {LoadingController, NavController, Slides} from 'ionic-angular';
import {HomeService} from "./home.service";
import {CommonService} from "../../core/common.service";
import {Storage} from "@ionic/storage";
import {MineService} from "../mine/mine.service";
import {TabService} from "../../core/tab.service";
import {InAppBrowser} from "@ionic-native/in-app-browser";
import {AppService} from "../../app/app.service";
import {StatusBar} from "@ionic-native/status-bar";
import * as Mock from 'mockjs';
import {ContactPage} from "./contact/contact";
import {DoVerityPage} from "./do-verity/do-verity";
import {DoSupervisePage} from "./do-supervise/do-supervise";
import {DataReportPage} from "./data-report/data-report";
import {PersonPage} from "../mine/person/person";

@Component({
    selector: 'page-home',
    templateUrl: 'home.html'
})
export class HomePage {

    echartData;
    type = 'teacher';

    info = {
        new: 0,
    };

    wow;   //是否执行动画
    unitsInfo;
    mineInfo;  //个人信息

    constructor(public navCtrl: NavController, public homeSer: HomeService, private loadCtrl: LoadingController,
                private commonSer: CommonService, private storage: Storage,
                private appSer: AppService, public statusBar: StatusBar,
                private mineSer: MineService, private tabSer: TabService, private inAppBrowser: InAppBrowser,
                private renderer: Renderer2) {
        this.storage.get('mineInfo').then(
            (value) => {
                this.mineInfo = value;
            }
        )
    }

    ionViewDidLoad() {
        Mock.mock(/mockjs/, "post", {
            "data":
                {
                    "unitcount": "7749",
                    "bianzhicount": "524845",
                    "shiyoucount": '429171',
                }
        })
        this.getUnits();
    }

    //单位数据
    getUnits() {
        const data = {
            yearMonth: "2019-10",
        };
        this.homeSer.units(data).subscribe(
            (res) => {
                this.unitsInfo = res.data;
                const ser = [
                    {name: "单位数", value: this.unitsInfo.unitcount},
                    {name: "编制数", value: this.unitsInfo.bianzhicount},
                    {name: "实有数", value: this.unitsInfo.shiyoucount},
                ];
                this.echartData = {
                    grid: {
                        left: "3%",
                        right: "4%",
                        bottom: "3%",
                        width: "100%",
                        height: "100%",
                        containLabel: true
                    },
                    tooltip : {
                        trigger: 'axis',
                        axisPointer : {            // 坐标轴指示器，坐标轴触发有效
                            type : 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
                        }
                    },
                    xAxis: {
                        type: 'category',
                        data: ser.map(e => {
                            return e.name
                        })
                    },
                    yAxis: {
                        type: 'value',
                    },
                    series: [
                        {
                            data: ser.map(e => {
                                return e.value
                            }),
                            color: ['#58afed'], //折线颜色
                            type: 'bar',
                            name: '柱状图',

                        },
                        {
                            data: ser.map(e => {
                                return e.value
                            }),
                            color: ['#d77ab1'], //折线颜色
                            type: 'line',
                            name: '折线图',
                        }
                    ]
                };
            }
        )
    }


    goToContact() {
        this.navCtrl.push(ContactPage);
    }

    //审核审批
    goToVerity() {
        this.navCtrl.push(DoVerityPage);
    }

    //办理督办
    goToSupervise() {
        this.navCtrl.push(DoSupervisePage);
    }

    //数据报表
    goToReport() {
        this.navCtrl.push(DataReportPage);
    }

    sendReq() {
        const data = {
            "userid": "",
            "mobile": "13225825208",
            "password": "000000",
            "rememberMe": true,
            "newestVersion": "4.6.0"
        };
        this.homeSer.loginpost(data).subscribe(
            (res) => {
                console.log(res);
            }
        )
    }

    goToPersonInfo() {
        this.navCtrl.push(PersonPage)
    }
}
